==> better-admin-ui-vue-0.0.1.tgz: package/es/components/TableOptions/TableOptions.js <==
/**
 * @Date: 2020/8/14 2:27 下午
 * @Author: Fioanna
 * @Description: 表格操作按钮
 */
import ADivider from 'ant-design-vue/es/divider';
import AIcon from 'ant-design-vue/es/icon';
import AMenu from 'ant-design-vue/es/menu';
import ADropdown from 'ant-design-vue/es/dropdown';
import tableOptionsProps from './types';
var AMenuItem = AMenu.Item; // const list = [
//   {
//     text: '查看',
//     click: () => {
//       console.log('点击查看')
//     }
//   },
//   {
//     text: '编辑',
//     click: () => {
//       console.log('点击编辑')
//     }
//   },
//   {
//     text: '更多',
//     children: [{ text: '按钮名称', click: () => {} }]
//   }
// ]

export default {
  name: 'ETableOptions',
  components: {
    ADivider: ADivider,
    AIcon: AIcon,
    AMenu: AMenu,
    AMenuItem: AMenuItem,
    ADropdown: ADropdown
  },
  props: tableOptionsProps,
  data: function data() {
    return {
      // 更多的按钮参数列表，结构：[{ text: '按钮名称', click: () => {} }]
      moreOptionList: []
    };
  },
  methods: {
    /**
     * 判断按钮是否展示
     * @param item
     * @returns {boolean}
     * @private
     */
    _isShow: function _isShow(item) {
      // 没有show标记，默认展示，有的话必须返回true为展示
      return item.show === undefined || item.show === true;
    },

    /**
     * 点击更多菜单按钮
     * @param e
     * @private
     */
    _handleMenu: function _handleMenu(e) {
      var menuItem = this.moreOptionList[e.key];

      if (menuItem && menuItem.click) {
        menuItem.click(this.$props.context, menuItem.text);
      }
    }
  },
  render: function render(createElement) {
    var _this = this;

    var length = this.$props.list.length;
    var optionList = [];

    var _loop = function _loop(i) {
      // 是否加了一个新按钮
      var addNewOption = false;
      var item = _this.$props.list[i]; // 判断类型是更多，则初始化更多的菜单按钮

      var moreMenuList = item.children;

      if (moreMenuList) {
        var moreMenuListLength = moreMenuList.length;

        if (moreMenuListLength === 0) {
          return "continue";
        } // 先判断更多按钮的菜单项是否有满足条件的


        var menuItemDomList = [];

        for (var j = 0; j < moreMenuListLength; j++) {
          var moreMenuItem = moreMenuList[j];

          if (_this._isShow(moreMenuItem)) {
            menuItemDomList.push(createElement('a-menu-item', {
              key: j
            }, moreMenuItem.text));
          }
        } // 如果更多按钮的菜单列表下有展示的按钮，则添加更多按钮


        if (menuItemDomList.length > 0) {
          optionList.push(createElement('a-dropdown', {
            props: {
              trigger: ['click']
            }
          }, [createElement('a', {}, ['更多', createElement('a-icon', {
            props: {
              type: 'down'
            }
          })]), createElement('a-menu', {
            slot: 'overlay',
            on: {
              click: _this._handleMenu
            }
          }, menuItemDomList)]));
          _this.moreOptionList = item.children;
          addNewOption = true;
        }
      } else {
        if (_this._isShow(item)) {
          optionList.push(createElement('a', {
            on: {
              click: function click() {
                item.click(_this.$props.context, item.text);
              }
            }
          }, [item.text]));
          addNewOption = true;
        }
      } // 是否添加的新的按钮，有的话则新增一个竖着的分割线


      if (addNewOption) {
        optionList.push(createElement('a-divider', {
          props: {
            type: 'vertical'
          }
        }));
      }
    };

    for (var i = 0; i < length; i++) {
      var _ret = _loop(i);

      if (_ret === "continue") continue;
    }

    if (optionList.length > 0) {
      // 删除最后一个多余的竖分线
      optionList.splice(-1);
      return createElement('div', {}, optionList);
    } else {
      return createElement('div');
    }
  }
};

==> better-admin-ui-vue-0.0.12.tgz: package/es/components/TableOptions/TableOptions.js <==
/**
 * @Date: 2020/8/14 2:27 下午
 * @Author: Fioanna
 * @Description: 表格操作按钮
 */
import ADivider from 'ant-design-vue/es/divider';
import AIcon from 'ant-design-vue/es/icon';
import AMenu from 'ant-design-vue/es/menu';
import ADropdown from 'ant-design-vue/es/dropdown';
import tableOptionsProps from './types';
var AMenuItem = AMenu.Item; // const list = [
//   {
//     text: '查看',
//     click: () => {
//       console.log('点击查看')
//     }
//   },
//   {
//     text: '编辑',
//     click: () => {
//       console.log('点击编辑')
//     }
//   },
//   {
//     text: '更多',
//     children: [{ text: '按钮名称', click: () => {} }]
//   }
// ]

export default {
  name: 'ETableOptions',
  props: tableOptionsProps,
  data: function data() {
    return {
      // 更多的按钮参数列表，结构：[{ text: '按钮名称', click: () => {} }]
      moreOptionList: []
    };
  },
  methods: {
    /**
     * 判断按钮是否展示
     * @param item
     * @returns {boolean}
     * @private
     */
    _isShow: function _isShow(item) {
      // 没有show标记，默认展示，有的话必须返回true为展示
      return item.show === undefined || item.show === true;
    },

    /**
     * 点击更多菜单按钮
     * @param e
     * @private
     */
    _handleMenu: function _handleMenu(e) {
      var menuItem = this.moreOptionList[e.key];

      if (menuItem && menuItem.click) {
        menuItem.click(this.$props.context, menuItem.text);
      }
    }
  },
  render: function render(createElement) {
    var _this = this;

    var length = this.$props.list.length;
    var optionList = [];

    var _loop = function _loop(i) {
      // 是否加了一个新按钮
      var addNewOption = false;
      var item = _this.$props.list[i]; // 判断类型是更多，则初始化更多的菜单按钮

      var moreMenuList = item.children;

      if (moreMenuList) {
        var moreMenuListLength = moreMenuList.length;

        if (moreMenuListLength === 0) {
          return "continue";
        } // 先判断更多按钮的菜单项是否有满足条件的


        var menuItemDomList = [];

        for (var j = 0; j < moreMenuListLength; j++) {
          var moreMenuItem = moreMenuList[j];

          if (_this._isShow(moreMenuItem)) {
            menuItemDomList.push(createElement(AMenuItem, {
              key: j
            }, moreMenuItem.text));
          }
        } // 如果更多按钮的菜单列表下有展示的按钮，则添加更多按钮


        if (menuItemDomList.length > 0) {
          optionList.push(createElement(ADropdown, {
            props: {
              trigger: ['click']
            }
          }, [createElement('a', {}, ['更多', createElement(AIcon, {
            props: {
              type: 'down'
            }
          })]), createElement(AMenu, {
            slot: 'overlay',
            on: {
              click: _this._handleMenu
            }
          }, menuItemDomList)]));
          _this.moreOptionList = item.children;
          addNewOption = true;
        }
      } else {
        if (_this._isShow(item)) {
          optionList.push(createElement('a', {
            on: {
              click: function click() {
                item.click(_this.$props.context, item.text);
              }
            }
          }, [item.text]));
          addNewOption = true;
        }
      } // 是否添加的新的按钮，有的话则新增一个竖着的分割线


      if (addNewOption) {
        optionList.push(createElement(ADivider, {
          props: {
            type: 'vertical'
          }
        }));
      }
    };

    for (var i = 0; i < length; i++) {
      var _ret = _loop(i);

      if (_ret === "continue") continue;
    }

    if (optionList.length > 0) {
      // 删除最后一个多余的竖分线
      optionList.splice(-1);
      return createElement('div', {}, optionList);
    } else {
      return createElement('div');
    }
  }
};
